pub struct Timestamp {
pub seconds: u32,
pub quarter_nanos: u32,
}Expand description
A representation of a hardware packet timestamp.
This is a reading of the device’s own clock, not of the Instant the stack is polled
with. Such a clock is usually called a “PTP hardware clock” or PHC. It has an arbitrary
epoch (often, but not necessarily, the time since the device was reset) and it drifts
with respect to any other clock in the system unless something is actively disciplining
it. Do not mix Timestamp and Instant values.
Fields
seconds: u32Whole seconds.
quarter_nanos: u32Fraction of a second, in units of 0.25 nanoseconds.
Always less than 4_000_000_000, i.e. less than one whole second.
Implementations